@@ -1,5 +1,11 @@
 from .register import Verification, Registration
 from .block import Block
 from .group import GroupCreate, GroupUpdate, GroupOut
-from .message import MessageIncoming, MessageOutgoing, MessageSent, AttachmentIn, ReactionOut
+from .message import (
+    MessageIncoming,
+    MessageOutgoing,
+    MessageSent,
+    AttachmentIn,
+    ReactionOut,
+)
 from .profile import ProfileUpdate
